<?php

namespace Monarch;

/**
 * String comparison helpers.
 */
class Strings {

  /**
   * Compare strings to get a fraction of similarity.
   *
   * @param string $a
   *   The first string to compare.
   * @param string $b
   *   The second string to compare.
   *
   * @return float
   *   The fraction of similarity between the two strings. Multiply by
   *   100 to get the percentage of similarity.
   */
  public static function compareWithCase(string $a, string $b) : float {
    $len = (strlen($a) + strlen($b)) / 2;
    return $len ? max(0.0, 1.0 - levenshtein($a, $b) / $len) : 0.0;
  }

  /**
   * Compare strings (ignoring case) to get a fraction of similarity.
   *
   * @param string $a
   *   The first string to compare.
   * @param string $b
   *   The second string to compare.
   *
   * @return float
   *   The fraction of similarity between the two strings. Multiply by
   *   100 to get the percentage of similarity.
   */
  public static function compare(string $a, string $b) : float {
    $a = strtolower($a);
    $b = strtolower($b);
    return static::compareWithCase($a, $b);
  }

  /**
   * Compare strings phonetically to get a fraction of similarity.
   *
   * @param string $a
   *   The first string to compare.
   * @param string $b
   *   The second string to compare.
   *
   * @return float
   *   The fraction of phonetic similarity between the two strings. Multiply by
   *   100 to get the percentage of similarity.
   */
  public static function comparePhonetics(string $a, string $b) : float {
    $a = metaphone($a);
    $b = metaphone($b);
    return static::compareWithCase($a, $b);
  }

}
