<?php

namespace Monarch;

/**
 * The class that provides the render array for the app.
 */
class VueApp {

  /**
   * The app name.
   *
   * @var string
   */
  protected string $appName;

  /**
   * The app name attribute.
   *
   * @var string
   */
  protected string $appNameAttribute;

  /**
   * The libraries to attach.
   *
   * @var array
   */
  protected array $libraries;

  /**
   * Construct the app class.
   *
   * @param string $app_name
   *   The name of the app.
   * @param array|null $libraries
   *   The libraries to attach.
   * @param string $app_name_attribute
   *   The attribute to use for the app name. Defaults to 'data-vue-app'.
   */
  public function __construct(string $app_name, array $libraries, string $app_name_attribute = 'data-vue-app') {
    $this->appName = $app_name;
    $this->libraries = $libraries;
    $this->appNameAttribute = $app_name_attribute;
  }

  /**
   * Instantiate the app class.
   *
   * @param string $app_name
   *   The name of the app.
   * @param array|null $libraries
   *   The libraries to attach.
   * @param string $app_name_attribute
   *   The attribute to use for the app name. Defaults to 'data-vue-app'.
   *
   * @return static
   *   The constructed class.
   */
  public static function create(string $app_name, array $libraries, string $app_name_attribute = 'data-vue-app') {
    return new static($app_name, $libraries, $app_name_attribute);
  }

  /**
   * The render function for the app.
   *
   * @param mixed $data
   *   The data provided to the app.
   *
   * @return array
   *   The render array for the app.
   */
  public function render($data) {
    $ret = [
      '#type' => 'inline_template',
      '#template' => '<div {{ app_name_attribute }}="{{ app_name|escape(\'html_attr\') }}" data-vue-app-data="{{ data|escape(\'html_attr\') }}"></div>',
      '#context' => [
        'app_name' => $this->appName,
        'app_name_attribute' => $this->appNameAttribute,
        'data' => json_encode($data),
      ],
      '#attached' => [
        'library' => $this->libraries,
      ],
      '#cache' => [
        'max-age' => 0,
      ],
    ];

    return $ret;
  }

}
